@@ -1,6 +1,3 @@
-import json
-from urllib import urlencode
-
 from social.backends.oauth import BaseOAuth2
 
 
@@ -9,6 +6,7 @@ class StocktwitsOAuth2(BaseOAuth2):
     name = 'stocktwits'
     AUTHORIZATION_URL = 'https://api.stocktwits.com/api/2/oauth/authorize'
     ACCESS_TOKEN_URL = 'https://api.stocktwits.com/api/2/oauth/token'
+    ACCESS_TOKEN_METHOD = 'POST'
     SCOPE_SEPARATOR = ','
     DEFAULT_SCOPE = ['read', 'publish_messages', 'publish_watch_lists',
                      'follow_users', 'follow_stocks']
@@ -31,9 +29,7 @@ class StocktwitsOAuth2(BaseOAuth2):
 
     def user_data(self, access_token, *args, **kwargs):
         """Loads user data from service"""
-        url = 'https://api.stocktwits.com/api/2/account/verify.json?' + \
-                    urlencode({'access_token': access_token})
-        try:
-            return json.load(self.urlopen(url))
-        except ValueError:
-            return None
+        return self.get_json(
+            'https://api.stocktwits.com/api/2/account/verify.json',
+            params={'access_token': access_token}
+        )
